@@ -1,4 +1,4 @@
-/* $Id: search.c,v 1.123.2.4 2004/02/18 04:33:53 astyanax Exp $ */
+/* $Id: search.c,v 1.123.2.5 2004/06/26 00:23:40 astyanax Exp $ */
 /**************************************************************************
  *   search.c                                                             *
  *                                                                        *
@@ -817,8 +817,12 @@ int do_replace(void)
 
 int do_gotoline(int line, int save_pos)
 {
+    static char *linestr = NULL;
+
+    linestr = mallocstrcpy(linestr, answer);
+
     if (line <= 0) {		/* Ask for it */
-	int st = statusq(FALSE, goto_list, line != 0 ? answer : "",
+	int st = statusq(FALSE, goto_list, line != 0 ? linestr : "",
 #ifndef NANO_SMALL
 			NULL,
 #endif
